summaryrefslogtreecommitdiffstats
path: root/libksirtet/lib/meeting.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libksirtet/lib/meeting.cpp')
-rw-r--r--libksirtet/lib/meeting.cpp60
1 files changed, 30 insertions, 30 deletions
diff --git a/libksirtet/lib/meeting.cpp b/libksirtet/lib/meeting.cpp
index 2cb6e285..71df0e4d 100644
--- a/libksirtet/lib/meeting.cpp
+++ b/libksirtet/lib/meeting.cpp
@@ -1,7 +1,7 @@
#include "meeting.h"
-#include <qmessagebox.h>
-#include <qpushbutton.h>
+#include <tqmessagebox.h>
+#include <tqpushbutton.h>
#include <klocale.h>
#include <kmessagebox.h>
@@ -14,7 +14,7 @@
NetMeeting::NetMeeting(const cId &_id, Socket *socket,
MPOptionWidget *option,
- bool _server, QWidget *parent, const char * name)
+ bool _server, TQWidget *parent, const char * name)
: KDialogBase(Plain, i18n("Network Meeting"),
(_server ? Ok|Cancel|Help : Cancel|Help),
(_server ? Ok : Cancel), parent, name),
@@ -24,8 +24,8 @@ NetMeeting::NetMeeting(const cId &_id, Socket *socket,
sm[0]->notifier()->setEnabled(TRUE);
/* top layout */
- QVBoxLayout *top = new QVBoxLayout(plainPage(), spacingHint());
- top->setResizeMode(QLayout::Fixed);
+ TQVBoxLayout *top = new TQVBoxLayout(plainPage(), spacingHint());
+ top->setResizeMode(TQLayout::Fixed);
// server line
spl = new MeetingLine(server, server, true, plainPage());
@@ -36,7 +36,7 @@ NetMeeting::NetMeeting(const cId &_id, Socket *socket,
wl->hide();
top->addWidget(wl);
- labWait = new QLabel(i18n("Waiting for clients"), plainPage());
+ labWait = new TQLabel(i18n("Waiting for clients"), plainPage());
labWait->setAlignment(AlignCenter);
top->addWidget(labWait);
@@ -44,7 +44,7 @@ NetMeeting::NetMeeting(const cId &_id, Socket *socket,
// if (ow) top->addWidget(ow); #### FIXME
// status bar
- status = new QStatusBar(plainPage());
+ status = new TQStatusBar(plainPage());
status->setSizeGripEnabled(false);
top->addWidget(status);
@@ -65,13 +65,13 @@ void NetMeeting::appendLine(const MeetingLineData &pld, bool server)
{
MeetingLine *pl;
pl = new MeetingLine(pld.own, server, false, wl);
- if (pld.own) connect(pl, SIGNAL(textChanged(const QString &)),
- SLOT(textChanged(const QString &)));
+ if (pld.own) connect(pl, TQT_SIGNAL(textChanged(const TQString &)),
+ TQT_SLOT(textChanged(const TQString &)));
else message(i18n("A new client has just arrived (#%1)")
.arg(wl->size()+1));
pl->setData(pld.ed);
- connect(pl, SIGNAL(typeChanged(MeetingCheckBox::Type)),
- SLOT(typeChanged(MeetingCheckBox::Type)));
+ connect(pl, TQT_SIGNAL(typeChanged(MeetingCheckBox::Type)),
+ TQT_SLOT(typeChanged(MeetingCheckBox::Type)));
wl->append(pl);
waiting();
}
@@ -122,7 +122,7 @@ bool NetMeeting::ready() const
return ( nbReady!=0 );
}
-void NetMeeting::cleanReject(const QString &str)
+void NetMeeting::cleanReject(const TQString &str)
{
sm.clean(); // remove the sockets immediately to avoid possible further mess
if ( !str.isEmpty() )
@@ -205,7 +205,7 @@ void NetMeeting::accept()
KDialogBase::accept();
}
-void NetMeeting::message(const QString &str)
+void NetMeeting::message(const TQString &str)
{
status->message(str, 3000);
}
@@ -213,20 +213,20 @@ void NetMeeting::message(const QString &str)
/** ServerNetMeeting *********************************************************/
ServerNetMeeting::ServerNetMeeting(const cId &id,
const RemoteHostData &r, MPOptionWidget *option,
- QPtrList<RemoteHostData> &arhd, QWidget *parent, const char * name)
+ TQPtrList<RemoteHostData> &arhd, TQWidget *parent, const char * name)
: NetMeeting(id, r.socket, option, TRUE, parent, name), rhd(arhd)
{
- connect(sm[0]->notifier(), SIGNAL(activated(int)), SLOT(newHost(int)));
+ connect(sm[0]->notifier(), TQT_SIGNAL(activated(int)), TQT_SLOT(newHost(int)));
players.append(Accepted); // server
// set server line
ExtData ed(r.bds, "", MeetingCheckBox::Ready);
spl->setData(ed);
- connect(spl, SIGNAL(textChanged(const QString &)),
- SLOT(textChanged(const QString &)));
+ connect(spl, TQT_SIGNAL(textChanged(const TQString &)),
+ TQT_SLOT(textChanged(const TQString &)));
// options signal
- if (ow) connect(ow, SIGNAL(changed()), SLOT(optionsChanged()));
+ if (ow) connect(ow, TQT_SIGNAL(changed()), TQT_SLOT(optionsChanged()));
}
void ServerNetMeeting::writeToAll(uint i)
@@ -238,13 +238,13 @@ void ServerNetMeeting::writeToAll(uint i)
sm.commonWritingStream().clear();
}
-void ServerNetMeeting::netError(uint i, const QString &type)
+void ServerNetMeeting::netError(uint i, const TQString &type)
{
Q_ASSERT( i!=0 );
disconnectHost(i, i18n("%1 client #%2: disconnect it").arg(type).arg(i));
}
-void ServerNetMeeting::disconnectHost(uint i, const QString &str)
+void ServerNetMeeting::disconnectHost(uint i, const TQString &str)
{
sm.remove(i, true);
socketRemoved = TRUE;
@@ -271,8 +271,8 @@ void ServerNetMeeting::newHost(int)
players.append(NewPlayer);
Socket *socket = new Socket(s, true);
uint i = sm.append(socket, SocketManager::ReadWrite);
- connect(sm[i]->notifier(), SIGNAL(activated(int)),
- SLOT(readNotifier(int)));
+ connect(sm[i]->notifier(), TQT_SIGNAL(activated(int)),
+ TQT_SLOT(readNotifier(int)));
sm[i]->notifier()->setEnabled(TRUE);
}
@@ -341,7 +341,7 @@ void ServerNetMeeting::modTextFlag(uint i)
{
checkState(i-1, Accepted);
// the client i has just sent a new text (QString)
TextInfo ti;
sm[i]->readingStream() >> ti.text;
CHECK_READ(i);
@@ -369,7 +369,7 @@ void ServerNetMeeting::modTypeFlag(uint i)
writeToAll(i);
}
-void ServerNetMeeting::textChanged(const QString &text)
+void ServerNetMeeting::textChanged(const TQString &text)
{
// server line text changed : send to every clients (Mod_Text flag + TextInfo struct)
TextInfo ti; ti.i = 0; ti.text = text;
@@ -448,11 +448,11 @@ void ServerNetMeeting::optionsChanged()
/** ClientNetMeeting *********************************************************/
ClientNetMeeting::ClientNetMeeting(const cId &id,
const RemoteHostData &rhd, MPOptionWidget *option,
- QWidget *parent, const char * name)
+ TQWidget *parent, const char * name)
: NetMeeting(id, rhd.socket, option, FALSE, parent, name), bds(rhd.bds)
{
- connect(sm[0]->notifier(), SIGNAL(activated(int)),
- SLOT(readNotifier(int)));
+ connect(sm[0]->notifier(), TQT_SIGNAL(activated(int)),
+ TQT_SLOT(readNotifier(int)));
players.append(NewPlayer); // server player
// Send id to server (Id flag + Id struct)
@@ -460,7 +460,7 @@ ClientNetMeeting::ClientNetMeeting(const cId &id,
writeToAll(); // what happens if there is a message box appearing before exec() call ??
}
-void ClientNetMeeting::netError(uint, const QString &str)
+void ClientNetMeeting::netError(uint, const TQString &str)
{
cleanReject(i18n("%1 server: aborting connection.").arg(str));
}
@@ -532,9 +532,9 @@ void ClientNetMeeting::delFlag(uint)
message(i18n("Client %1 has left").arg(k));
}
-void ClientNetMeeting::textChanged(const QString &text)
+void ClientNetMeeting::textChanged(const TQString &text)
{
// text changed : send to server (Mod_Text flag + QString)
sm.commonWritingStream() << Mod_TextFlag << text;
writeToAll();
}
@@ -341,7 +341,7 @@ void ServerNetMeeting::modTextFlag(uint i)
{
checkState(i-1, Accepted);
- // the client i has just sent a new text (QString)
+ // the client i has just sent a new text (TQString)
TextInfo ti;
sm[i]->readingStream() >> ti.text;
@@ -532,9 +532,9 @@ void ClientNetMeeting::delFlag(uint)
{
- // text changed : send to server (Mod_Text flag + QString)
+ // text changed : send to server (Mod_Text flag + TQString)
sm.commonWritingStream() << Mod_TextFlag << text;
writeToAll();